backup — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- wizard »

# backup

class `camelot.view.wizard.backup.` `BackupWizard`(backup_mechanism, parent=None)

  Wizard to perform a backup using a BackupMechanism

class `camelot.view.wizard.backup.` `RestoreWizard`(backup_mechanism, parent=None)

  Wizard to perform a restore using a BackupMechanism

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- wizard »

Comments
blog comments powered by Disqus